@@ -1,3 +1,22 @@
+/*
+ * Copyright 2005, 2006 University of Leiden.
+ *
+ * This file is part of MIA+EWS.
+ *
+ * MIA+EWS is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * MIA+EWS is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with MIA; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -12,7 +31,7 @@
 #define PRISMBOTTOM 9
 #define GRISMBOTTOM 6
 #define CURVEDY     8
-#define maxshift    4
+#define maxshift    6	/* Changed to 6 from 4 by CAH */
 #define DSKYUT     10
 #define DSKYAT      6
 /*#define DEBUG 1 */
